ImageClipEncodedFormat enum

Encoded image container formats recognized before full decoding.

Inheritance
Available extensions

Values

png → const ImageClipEncodedFormat

PNG input bytes.

jpeg → const ImageClipEncodedFormat

JPEG input bytes.

gif → const ImageClipEncodedFormat

GIF input bytes.

webp → const ImageClipEncodedFormat

WebP input bytes.

heic → const ImageClipEncodedFormat

HEIC input bytes.

heif → const ImageClipEncodedFormat

HEIF input bytes.

unknown → const ImageClipEncodedFormat

The input header is not recognized.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ImageClipEncodedFormat>
A constant List of the values in this enum, in order of their declaration.