ImageClipOutputSettings class

Encoding options used when an image operation writes output bytes.

Constructors

ImageClipOutputSettings({ImageClipOutputFormat format = ImageClipOutputFormat.png, int jpegQuality = 90, int pngLevel = 6})
Creates output encoding settings.
const
ImageClipOutputSettings.jpeg({int jpegQuality = 90})
Creates JPEG output settings.
const
ImageClipOutputSettings.png({int pngLevel = 6})
Creates lossless PNG output settings.
const

Properties

fileExtension String
File extension for format, without a leading dot.
no setter
format ImageClipOutputFormat
Encoded output format.
final
hashCode int
The hash code for this object.
no setteroverride
jpegQuality int
JPEG quality from 1 to 100.
final
mimeType String
MIME type for format.
no setter
pngLevel int
PNG compression level from 0 to 9.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ImageClipOutputFormat? format, int? jpegQuality, int? pngLevel}) ImageClipOutputSettings
Returns a copy with selected values replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Converts these settings to the map used by the background processor.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromMap(Map<Object?, Object?>? map) ImageClipOutputSettings
Creates settings from the map used by the background processor.