ImageClipProcessingException class
Thrown when an image processing operation fails.
- Inheritance
-
- Object
- ImageClipException
- ImageClipProcessingException
Constructors
- ImageClipProcessingException(String message, {Object? cause})
-
Creates a processing exception.
const
Properties
- cause → Object?
-
Optional lower-level error that caused this exception.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited