ImageClipProcessingSettings class
Runtime guardrails for decoding and writing image pixels.
Constructors
- ImageClipProcessingSettings({int? maxInputPixels = 48000000, int? maxOutputPixels = 16000000, bool autoDownscale = true})
-
Creates processing settings.
const
- ImageClipProcessingSettings.unrestricted()
-
Creates settings without input or output pixel limits.
const
Properties
- autoDownscale → bool
-
Whether output images larger than maxOutputPixels should be resized.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxInputPixels → int?
-
Maximum decoded input pixels before processing starts.
final
- maxOutputPixels → int?
-
Maximum output pixels after processing.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? maxInputPixels, int? maxOutputPixels, bool? autoDownscale, bool clearMaxInputPixels = false, bool clearMaxOutputPixels = false}) → ImageClipProcessingSettings - Returns a copy with selected values replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Converts these settings to the map used by the background processor.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromMap(
Map< Object?, Object?> ? map) → ImageClipProcessingSettings - Creates settings from the map used by the background processor.