ImageClipPipelineStep class
One transformation inside an ImageClipPipeline.
Constructors
- ImageClipPipelineStep.adjustColor(ColorAdjustment adjustment)
-
Adds a brightness, contrast, and saturation adjustment.
const
- ImageClipPipelineStep.cropCenter(CropSettings settings)
-
Adds a center-crop transformation.
const
- ImageClipPipelineStep.cropRegion(CropRegion region)
-
Adds an explicit pixel crop transformation.
const
- ImageClipPipelineStep.flipHorizontal()
-
Adds a horizontal flip transformation.
const
- ImageClipPipelineStep.flipVertical()
-
Adds a vertical flip transformation.
const
- ImageClipPipelineStep.resizeLongSide(int maxSide)
-
Adds a resize transformation that constrains the longest side.
const
- ImageClipPipelineStep.rotate({int degrees = 90})
-
Adds a clockwise rotation transformation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> - Converts this step to the map used by the background processor.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited