ImageClipTaskOptions class
Options for a cancelable image processing task.
Constructors
- ImageClipTaskOptions({Duration? timeout, void onProgress(ImageClipTaskProgress progress)?})
-
Creates task options.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onProgress → void Function(ImageClipTaskProgress progress)?
-
Optional callback invoked for every progress event.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration?
-
Optional timeout after which the task is canceled.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited